summaryrefslogtreecommitdiffstats
path: root/tdecore/network/khttpproxysocketdevice.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /tdecore/network/khttpproxysocketdevice.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/network/khttpproxysocketdevice.h')
-rw-r--r--tdecore/network/khttpproxysocketdevice.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/network/khttpproxysocketdevice.h b/tdecore/network/khttpproxysocketdevice.h
index 903d7aa6f..dc5faef93 100644
--- a/tdecore/network/khttpproxysocketdevice.h
+++ b/tdecore/network/khttpproxysocketdevice.h
@@ -35,18 +35,18 @@ class KHttpProxySocketDevicePrivate;
* @class KHttpProxySocketDevice khttpproxysocketdevice.h khttproxysocketdevice.h
* @brief The low-level backend for HTTP proxying.
*
* This class derives from @ref KSocketDevice and implements the necessary
* calls to make a connection through an HTTP proxy.
*
* @author Thiago Macieira <thiago.macieira@kdemail.net>
*/
-class TDECORE_EXPORT KHttpProxySocketDevice: public KSocketDevice
+class TDECORE_EXPORT KHttpProxySocketDevice: public TDESocketDevice
{
public:
/**
* Constructor.
*/
- KHttpProxySocketDevice(const KSocketBase* = 0L);
+ KHttpProxySocketDevice(const TDESocketBase* = 0L);
/**
* Constructor with proxy server's address.
@@ -92,13 +92,13 @@ public:
/**
* Return the peer address.
*/
- virtual KSocketAddress peerAddress() const;
+ virtual TDESocketAddress peerAddress() const;
/**
* Return the externally visible address. We can't tell what that address is,
* so this function always returns an empty object.
*/
- virtual KSocketAddress externalAddress() const;
+ virtual TDESocketAddress externalAddress() const;
private:
/**
@@ -35,18 +35,18 @@ class KHttpProxySocketDevicePrivate;
* @brief The low-level backend for HTTP proxying.
*
- * This class derives from @ref KSocketDevice and implements the necessary
+ * This class derives from @ref TDESocketDevice and implements the necessary
* calls to make a connection through an HTTP proxy.
*